Crate qurust

source ·
qurust library is a collection of modules used for working with quantum programs and circuits.

Module qasm3 serves as a set of modules used for representation and parsing of OpenQASM3 programs. We refer to OpenQASM3 as QASM3 for short. For more information and an example, see the module documentation.

Modules

  • QASM3 meta program representation and parsing.